@@ -168,7 +168,8 @@ impl Emulator for ArschitekZeroEmulator {
                     instruction.inputs[0] = template_data.reg1;
                     instruction.memory_address = (self.registers[template_data.reg1 as usize]
                         .wrapping_add(sign_extend_u4(template_data.reg2_imm4))
-                        as usize) << 1;
+                        as usize)
+                        << 1;
                     if address == self.ip {
                         self.retired_instruction_count
                             .fetch_add(1, Ordering::Relaxed);
@@ -186,7 +187,8 @@ impl Emulator for ArschitekZeroEmulator {
                     instruction.inputs[1] = template_data.reg1;
                     instruction.memory_address = (self.registers[template_data.reg1 as usize]
                         .wrapping_add(sign_extend_u4(template_data.reg2_imm4) << 1)
-                        as usize) << 1;
+                        as usize)
+                        << 1;
                     if address == self.ip {
                         self.retired_instruction_count
                             .fetch_add(1, Ordering::Relaxed);
@@ -202,7 +204,8 @@ impl Emulator for ArschitekZeroEmulator {
                     instruction.inputs[0] = template_data.reg0;
                     instruction.branch_address = (self.registers[template_data.reg0 as usize]
                         .wrapping_add(template_data.imm8)
-                        as usize) << 1;
+                        as usize)
+                        << 1;
                     if address == self.ip {
                         self.retired_instruction_count
                             .fetch_add(1, Ordering::Relaxed);
@@ -342,8 +345,10 @@ impl Emulator for ArschitekZeroEmulator {
                             self.ip
                         )
                         .unwrap();
-                        writeln!(self.output_buffer, "Register |  !sign | signed |    hex").unwrap();
-                        writeln!(self.output_buffer, "---------+--------+--------+-------").unwrap();
+                        writeln!(self.output_buffer, "Register |  !sign | signed |    hex")
+                            .unwrap();
+                        writeln!(self.output_buffer, "---------+--------+--------+-------")
+                            .unwrap();
                         for (i, &reg) in self.registers.iter().enumerate() {
                             writeln!(
                                 self.output_buffer,
